import { useState, useEffect } from 'react';
import { Button } from '@/components/ui/button';
import { Card } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import { Separator } from '@/components/ui/separator';
import CookieConsent from '@/components/CookieConsent';
import SocialShare from '@/components/SocialShare';
import { optimizedLocalStorage } from '@/utils/performance';

type Choice = 'rock' | 'paper' | 'scissors' | null;
type Result = 'win' | 'lose' | 'tie' | null;

const Index = () => {
  useEffect(() => {
    // SEO meta tags for indexable home page
    document.title = 'Rock Paper Scissors - Free Online Game | Play Now';
    
    // Remove any existing meta description and add new one
    const existingDesc = document.querySelector('meta[name="description"]');
    if (existingDesc) existingDesc.remove();
    
    const metaDesc = document.createElement('meta');
    metaDesc.name = 'description';
    metaDesc.content = 'Play the classic Rock Paper Scissors game online for free. Challenge the computer, track your score, and share with friends. No download required - start playing now!';
    document.head.appendChild(metaDesc);
    
    // Add meta keywords
    const existingKeywords = document.querySelector('meta[name="keywords"]');
    if (existingKeywords) existingKeywords.remove();
    
    const metaKeywords = document.createElement('meta');
    metaKeywords.name = 'keywords';
    metaKeywords.content = 'rock paper scissors, online game, free game, browser game, computer game, classic game, fun game, casual game, multiplayer, score tracking';
    document.head.appendChild(metaKeywords);
    
    // Ensure page is indexable
    const existingRobots = document.querySelector('meta[name="robots"]');
    if (existingRobots) existingRobots.remove();
    
    const metaRobots = document.createElement('meta');
    metaRobots.name = 'robots';
    metaRobots.content = 'index, follow';
    document.head.appendChild(metaRobots);
  }, []);

  const [playerChoice, setPlayerChoice] = useState<Choice>(null);
  const [computerChoice, setComputerChoice] = useState<Choice>(null);
  const [result, setResult] = useState<Result>(null);
  const [playerScore, setPlayerScore] = useState(0);
  const [computerScore, setComputerScore] = useState(0);
  const [isPlaying, setIsPlaying] = useState(false);
  const [totalGamesPlayed, setTotalGamesPlayed] = useState(() => {
    const saved = optimizedLocalStorage.getItem('totalGamesPlayed');
    return saved ? parseInt(saved, 10) : 0;
  });

  const choices = [
    { name: 'rock', emoji: '🪨', label: 'Rock' },
    { name: 'paper', emoji: '📄', label: 'Paper' },
    { name: 'scissors', emoji: '✂️', label: 'Scissors' }
  ];

  const getRandomChoice = (): Choice => {
    const randomIndex = Math.floor(Math.random() * 3);
    return choices[randomIndex].name as Choice;
  };

  const determineWinner = (player: Choice, computer: Choice): Result => {
    if (player === computer) return 'tie';
    
    if (
      (player === 'rock' && computer === 'scissors') ||
      (player === 'paper' && computer === 'rock') ||
      (player === 'scissors' && computer === 'paper')
    ) {
      return 'win';
    }
    
    return 'lose';
  };

  const playGame = (choice: Choice) => {
    setIsPlaying(true);
    setPlayerChoice(choice);
    
    // Increment total games played with optimized storage
    const newTotal = totalGamesPlayed + 1;
    setTotalGamesPlayed(newTotal);
    optimizedLocalStorage.setItem('totalGamesPlayed', newTotal.toString());
    
    setTimeout(() => {
      const computerChoice = getRandomChoice();
      setComputerChoice(computerChoice);
      
      const gameResult = determineWinner(choice, computerChoice);
      setResult(gameResult);
      
      if (gameResult === 'win') {
        setPlayerScore(prev => prev + 1);
      } else if (gameResult === 'lose') {
        setComputerScore(prev => prev + 1);
      }
      
      setIsPlaying(false);
    }, 1000);
  };

  const resetGame = () => {
    setPlayerChoice(null);
    setComputerChoice(null);
    setResult(null);
    setPlayerScore(0);
    setComputerScore(0);
  };

  const getResultMessage = () => {
    if (!result) return '';
    if (result === 'win') return '🎉 You Win!';
    if (result === 'lose') return '😔 You Lose!';
    return "🤝 It's a Tie!";
  };

  const getResultColor = () => {
    if (result === 'win') return 'bg-green-500';
    if (result === 'lose') return 'bg-red-500';
    return 'bg-yellow-500';
  };

  return (
    <div className="min-h-screen bg-gradient-to-br from-purple-400 via-pink-500 to-red-500 flex items-center justify-center p-2 sm:p-4">
      <Card className="w-full max-w-md sm:max-w-2xl p-3 sm:p-6 md:p-8 bg-white/95 backdrop-blur-sm shadow-2xl">
        <header className="text-center mb-4 sm:mb-6">
          <h1 className="text-2xl sm:text-3xl md:text-5xl font-bold bg-gradient-to-r from-purple-600 to-pink-600 bg-clip-text text-transparent mb-1 sm:mb-2">
            Rock Paper Scissors - Free Online Game
          </h1>
          <p className="text-sm sm:text-base md:text-lg text-gray-600">Choose your weapon and battle the computer!</p>
        </header>

        {/* Score Display */}
        <section className="flex justify-center items-center gap-6 sm:gap-8 md:gap-12 mb-6 sm:mb-8" aria-label="Game Score">
          <h2 className="sr-only">Current Score</h2>
          <div className="text-center">
            <p className="text-base text-gray-500 mb-2">You</p>
            <Badge variant="outline" className="text-lg sm:text-xl md:text-2xl px-3 sm:px-4 py-2 border-blue-500 text-blue-600">
              {playerScore}
            </Badge>
          </div>
          <div className="text-center">
            <p className="text-base text-gray-500 mb-2">Computer</p>
            <Badge variant="outline" className="text-lg sm:text-xl md:text-2xl px-3 sm:px-4 py-2 border-red-500 text-red-600">
              {computerScore}
            </Badge>
          </div>
        </section>

        {/* Game Area */}
        <main className="grid grid-cols-3 gap-2 sm:gap-4 md:gap-8 mb-2 sm:mb-3" role="main" aria-label="Game Arena">
          <h2 className="sr-only">Game Arena</h2>
          
          {/* Player Side */}
          <div className="text-center">
            <h3 className="text-sm sm:text-base md:text-xl font-semibold mb-2 sm:mb-3 text-gray-700">Your Choice</h3>
            <div className="w-24 h-24 sm:w-32 sm:h-32 md:w-40 md:h-40 mx-auto flex items-center justify-center bg-blue-100 rounded-full border-2 sm:border-4 border-blue-300 transition-all duration-300 shadow-lg">
              {playerChoice && (
                <span className="text-4xl sm:text-5xl md:text-7xl animate-scale-in" role="img" aria-label={playerChoice}>
                  {choices.find(c => c.name === playerChoice)?.emoji}
                </span>
              )}
            </div>
          </div>

          {/* VS Divider */}
          <div className="flex flex-col items-center justify-center">
            <Separator orientation="vertical" className="h-8 sm:h-12 md:h-16 bg-gray-300" />
            <span className="text-sm sm:text-base text-gray-500 my-1 sm:my-2">VS</span>
            <Separator orientation="vertical" className="h-8 sm:h-12 md:h-16 bg-gray-300" />
          </div>

          {/* Computer Side */}
          <div className="text-center">
            <h3 className="text-sm sm:text-base md:text-xl font-semibold mb-2 sm:mb-3 text-gray-700">Computer's Choice</h3>
            <div className="w-24 h-24 sm:w-32 sm:h-32 md:w-40 md:h-40 mx-auto flex items-center justify-center bg-red-100 rounded-full border-2 sm:border-4 border-red-300 transition-all duration-300 shadow-lg">
              {isPlaying ? (
                <span className="text-4xl sm:text-5xl md:text-7xl animate-pulse" role="img" aria-label="thinking">
                  🤔
                </span>
              ) : computerChoice ? (
                <span className="text-4xl sm:text-5xl md:text-7xl animate-scale-in" role="img" aria-label={computerChoice}>
                  {choices.find(c => c.name === computerChoice)?.emoji}
                </span>
              ) : null}
            </div>
          </div>
        </main>

        {/* Result Display */}
        <section className="text-center mb-4 sm:mb-6 min-h-[40px] sm:min-h-[50px] flex items-center justify-center" aria-live="polite" aria-label="Game Result">
          <h2 className="sr-only">Game Result</h2>
          {result && (
            <div className={`inline-block px-3 sm:px-4 py-1 sm:py-2 rounded-full text-white font-bold text-base sm:text-lg ${getResultColor()} animate-fade-in`}>
              {getResultMessage()}
            </div>
          )}
        </section>

        {/* Choice Buttons */}
        <section className="grid grid-cols-3 gap-2 sm:gap-3 md:gap-4 mb-4 sm:mb-6" aria-label="Game Controls">
          <h2 className="sr-only">Game Controls</h2>
          {choices.map((choice) => (
            <Button
              key={choice.name}
              onClick={() => playGame(choice.name as Choice)}
              disabled={isPlaying}
              className="h-16 sm:h-20 md:h-24 bg-gradient-to-br from-gray-100 to-gray-200 hover:from-gray-200 hover:to-gray-300 text-gray-700 border-2 border-gray-300 hover:border-gray-400 transition-all duration-200 hover:scale-105 disabled:opacity-50 disabled:hover:scale-100"
              aria-label={`Choose ${choice.label}`}
            >
              <div className="text-center">
                <div className="text-2xl sm:text-3xl md:text-4xl mb-1" role="img" aria-label={choice.name}>
                  {choice.emoji}
                </div>
                <div className="text-sm sm:text-base font-medium">{choice.label}</div>
              </div>
            </Button>
          ))}
        </section>

        {/* Reset Button */}
        <footer className="text-center">
          <Button
            onClick={resetGame}
            variant="outline"
            className="px-4 sm:px-6 py-2 border-2 border-purple-300 text-purple-600 hover:bg-purple-50 transition-colors duration-200 mb-4 sm:mb-6 text-base sm:text-lg"
            aria-label="Reset the game score"
          >
            Reset Game
          </Button>
          
          {/* Social Share */}
          <SocialShare />
          
          {/* Discrete game statistics */}
          <div className="text-center mt-3 sm:mt-4 pt-2 border-t border-gray-200">
            <p className="text-sm text-gray-400">
              Games played: {totalGamesPlayed.toLocaleString()}
            </p>
          </div>
          
          {/* Legal Links */}
          <div className="flex flex-wrap justify-center gap-2 sm:gap-4 text-sm sm:text-base text-gray-500 border-t pt-3 sm:pt-4 mt-3 sm:mt-4">
            <a href="/terms" className="hover:text-purple-600 transition-colors duration-200">
              Terms of Service
            </a>
            <span>•</span>
            <a href="/privacy" className="hover:text-purple-600 transition-colors duration-200">
              Privacy Policy
            </a>
            <span>•</span>
            <a href="/legal" className="hover:text-purple-600 transition-colors duration-200">
              Legal Notice
            </a>
          </div>
        </footer>
      </Card>
      <CookieConsent />
    </div>
  );
};

export default Index;